==> ovirt-engine-4.0.6.tar.gz: backend/manager/modules/vdsbroker/src/main/java/org/ovirt/engine/core/vdsbroker/monitoring/MonitoringStrategyFactory.java <==
package org.ovirt.engine.core.vdsbroker.monitoring;

import javax.annotation.PostConstruct;
import javax.inject.Inject;
import javax.inject.Singleton;

import org.ovirt.engine.core.common.businessentities.Cluster;
import org.ovirt.engine.core.common.businessentities.VDS;
import org.ovirt.engine.core.dao.ClusterDao;
import org.ovirt.engine.core.dao.VdsDao;
import org.ovirt.engine.core.dao.VmDynamicDao;

/**
 * This class is responsible for returning the correct service strategy, according to the service the cluster supports
 */
@Singleton
public class MonitoringStrategyFactory {
    private MonitoringStrategy virtMonitoringStrategy;
    private MonitoringStrategy glusterMonitoringStrategy;
    private MultipleServicesMonitoringStrategy multipleMonitoringStrategy;

    @Inject
    private ClusterDao clusterDao;

    @Inject
    private VdsDao vdsDao;

    @Inject
    private VmDynamicDao vmDynamicDao;

    @PostConstruct
    private void init() {
        virtMonitoringStrategy = new VirtMonitoringStrategy(clusterDao, vdsDao, vmDynamicDao);
        glusterMonitoringStrategy = new GlusterMonitoringStrategy();
        multipleMonitoringStrategy = new MultipleServicesMonitoringStrategy();
        multipleMonitoringStrategy.addMonitoringStrategy(virtMonitoringStrategy);
        multipleMonitoringStrategy.addMonitoringStrategy(glusterMonitoringStrategy);
    }

    /**
     * This method gets the VDS, and returns the correct service strategy, according to the service the cluster that the VDS belongs to supports
     */
    public MonitoringStrategy getMonitoringStrategyForVds(VDS vds) {
        Cluster cluster = clusterDao.get(vds.getClusterId());

        if (cluster.supportsVirtService() && cluster.supportsGlusterService()) {
            return multipleMonitoringStrategy;
        }

        if (cluster.supportsVirtService()) {
            return virtMonitoringStrategy;
        }

        if (cluster.supportsGlusterService()) {
            return glusterMonitoringStrategy;
        }

        return virtMonitoringStrategy;
    }
}

==> ovirt-engine-4.4.5.11.tar.gz: backend/manager/modules/vdsbroker/src/main/java/org/ovirt/engine/core/vdsbroker/monitoring/MonitoringStrategyFactory.java <==
package org.ovirt.engine.core.vdsbroker.monitoring;

import javax.annotation.PostConstruct;
import javax.inject.Inject;
import javax.inject.Singleton;

import org.ovirt.engine.core.common.businessentities.Cluster;
import org.ovirt.engine.core.common.businessentities.VDS;
import org.ovirt.engine.core.dao.ClusterDao;

/**
 * This class is responsible for returning the correct service strategy, according to the service the cluster supports
 */
@Singleton
public class MonitoringStrategyFactory {

    @Inject
    private VirtMonitoringStrategy virtMonitoringStrategy;

    @Inject
    private GlusterMonitoringStrategy glusterMonitoringStrategy;

    private MultipleServicesMonitoringStrategy multipleMonitoringStrategy;

    @Inject
    private ClusterDao clusterDao;

    @PostConstruct
    private void init() {
        multipleMonitoringStrategy = new MultipleServicesMonitoringStrategy();
        multipleMonitoringStrategy.addMonitoringStrategy(virtMonitoringStrategy);
        multipleMonitoringStrategy.addMonitoringStrategy(glusterMonitoringStrategy);
    }

    /**
     * This method gets the VDS, and returns the correct service strategy, according to the service the cluster that the VDS belongs to supports
     */
    public MonitoringStrategy getMonitoringStrategyForVds(VDS vds) {
        Cluster cluster = clusterDao.get(vds.getClusterId());

        if (cluster.supportsVirtService() && cluster.supportsGlusterService()) {
            return multipleMonitoringStrategy;
        }

        if (cluster.supportsVirtService()) {
            return virtMonitoringStrategy;
        }

        if (cluster.supportsGlusterService()) {
            return glusterMonitoringStrategy;
        }

        return virtMonitoringStrategy;
    }
}
